#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import logging
import os
from subprocess import Popen, PIPE

from model.config import ERROR_LOG_PATH
from model.config import ERROR_ARCHIVE_PATH
from model.config import KICKSTART_FILE
from model.config import LIVECD_INSTALLER_LOG
from model.config import LIVECD_PARTITIONER_LOG
from model.config import LOG_FORMATTER
from model.config import POWERKVM_LOG_DIR


#
# CODE
#
def createLogger():
    """
    Creates a standard logger
    """
    logging.basicConfig(filename=LIVECD_INSTALLER_LOG,
                        level=logging.DEBUG,
                        format=LOG_FORMATTER)
    logger = logging.getLogger(__name__)
    logger.setLevel(logging.DEBUG)

    if not os.path.isdir(POWERKVM_LOG_DIR):
        os.makedirs(POWERKVM_LOG_DIR)

    return logger

def createFailureLog():
    """
    Create log after install failure
    """

    separator = "===================="
    cmd = []
    # General
    cmd.append("dmesg")
    cmd.append("systemctl status")
    cmd.append("journalctl -xb")
    cmd.append("cat /proc/cmdline")
    cmd.append("cat %s" % KICKSTART_FILE)
    # Network
    cmd.append("ifconfig -a")
    cmd.append("ip address")
    cmd.append("route -n")
    cmd.append("lspci -vv -k")
    cmd.append("ls -la /sys/class/net/")
    cmd.append("ls -la /sys/devices/virtual/net/")
    cmd.append("grep '' /sys/class/net/*/*")
    #cmd.append("cat /sys/class/net/*/carrier")
    #cmd.append("cat /sys/class/net/*/operstate")
    cmd.append("ls -la /etc/sysconfig/network-scripts/")
    cmd.append("cat /etc/sysconfig/network-scripts/ifcfg-*")
    # Disk
    cmd.append("iprconfig -c show-config")
    cmd.append("iprconfig -c show-alt-config")
    cmd.append("iprconfig -c show-ioas")
    cmd.append("multipath -l")
    cmd.append("dmsetup ls")
    cmd.append("pvscan")
    cmd.append("vgscan")
    cmd.append("lvscan")
    cmd.append("pvdisplay")
    cmd.append("vgdisplay")
    cmd.append("lvdisplay")
    cmd.append("ls -la /dev/sd*")
    cmd.append("ls -la /dev/mapper/")
    cmd.append("ls -la /dev/disk/*")
    cmd.append("ls -la /dev/dm-*")
    with open(ERROR_LOG_PATH, "a") as f:
        for i in cmd:
            proc = Popen(i, shell=True, stdout=PIPE, stderr=PIPE)
            out, err = proc.communicate()
            msg = ">>> COMMAND: %s" % i
            exitCode = ">>> Exit Code: %s" % proc.returncode
            if proc.returncode != 0:
                exitCode = exitCode + "\n>>> Error messsage: %s" % err
            output = ">>> OUTPUT:\n%s" % out
            f.write("%s\n%s\n%s\n%s\n" % (separator, msg, exitCode, output))
    tarCmd = "tar -zcvf %s %s %s %s" % (ERROR_ARCHIVE_PATH, ERROR_LOG_PATH, LIVECD_INSTALLER_LOG, LIVECD_PARTITIONER_LOG)
    proc = Popen(tarCmd.split(" "), stdout=PIPE, stderr=PIPE)
    out, err = proc.communicate()
