#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


from pykickstart.handlers.control import commandMap
from pykickstart.handlers.control import dataMap
from pykickstart.version import DEVEL

from controller.pkvmerror import PKVMError

LogVolData = dataMap[DEVEL]['LogVolData']
class Pkvm_LogVolData(LogVolData):
    def __init__(self, *args, **kwargs):
        LogVolData.__init__(self, *args, **kwargs)

    def __eq__(self, y):
        if not y:
            return False
        return self.vgname == y.vgname and self.mountpoint == y.mountpoint

LogVol = commandMap[DEVEL]['logvol']
class Pkvm_LogVol(LogVol):
    def __init__(self, *args, **kwargs):
        LogVol.__init__(self, *args, **kwargs)

    def _getParser(self):
        op = LogVol._getParser(self)
        op.remove_option("--name")
        return op

    def parse(self, args):
        logVolData = LogVol.parse(self, args)

        # Ensure that either all logvols have --noformat or none of them have.
        if self.handler.formatAllLVs is None:
            self.handler.formatAllLVs = logVolData.format
        else:
            if self.handler.formatAllLVs != logVolData.format:
                raise PKVMError("061")

        # when preserving logical volumes, do not specify the size
        if not logVolData.format and logVolData.size:
            raise PKVMError("060")

        if logVolData.mountpoint.endswith("/") and logVolData.mountpoint != "/":
            logVolData.mountpoint = logVolData.mountpoint[:-1]

        return logVolData
