#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import warnings

from pykickstart import constants
from pykickstart.base import *
from pykickstart.parser import *

from modules.installauto.pkvmkickstart.handler import PkvmHandler

#
# CODE
#
class PkvmKickstartParser():

    def __init__(self, followIncludes=True):
        """
        Args:
            followIncludes (bool): whether to check a file provided in
                %include section in the kickstart file
        """

        # using composition instead of inheritance here because
        # pykickstart will call readKickstartFromString internally and
        # cause unwanted behavior.
        self.ksParser = KickstartParser(handler=PkvmHandler(),
                                        followIncludes=followIncludes)

        self.followIncludes = followIncludes
        self.lang = ""
        self.logicalVolumes = []
        self.partitions = []
        self.volumeGroups = []
        self.tzMap = {
            "timezone": "",
            "isUTC": False,
            "nontp": False,
            "ntpservers": []
        }
        self.rootpw = {
            "password": "",
            "isCrypted": False,
        }
        self.networks = []
        self.preScripts = []
        self.postScripts = []

    def _initDataStructures(self):
        """
        Initialize the parser with data read from kickstart
        """

        self.lang = self.ksParser.handler.lang.lang
        self.logicalVolumes = self.ksParser.handler.logvol.lvList
        self.formatAllLVs = self.ksParser.handler.formatAllLVs
        self.partitions = self.ksParser.handler.partition.partitions
        self.volumeGroups = self.ksParser.handler.volgroup.vgList
        self.tzMap["timezone"] = self.ksParser.handler.timezone.timezone
        self.tzMap["isUTC"] = self.ksParser.handler.timezone.isUtc
        self.tzMap["nontp"] = self.ksParser.handler.timezone.nontp
        self.tzMap["ntpservers"] = self.ksParser.handler.timezone.ntpservers
        self.rootpw["password"] = self.ksParser.handler.rootpw.password
        self.rootpw["isCrypted"] = self.ksParser.handler.rootpw.isCrypted
        self.networks = self.ksParser.handler.network.network

        for script in self.ksParser.handler.scripts:
            if script.type == constants.KS_SCRIPT_PRE:
                self.preScripts.append(script)
            else:
                self.postScripts.append(script)

    def readKickstartFromString(self, ks):
        """
        Process a kickstart file, provided as a string

        Args:
            ks (str): kickstart file converted to a string
        """

        with warnings.catch_warnings():
            warnings.filterwarnings('error')
            self.ksParser.readKickstartFromString(ks)
        if self.followIncludes:
            # do not validate before parsing %include because all the
            # commands might be in the included file
            self.ksParser.handler.validate()
        self._initDataStructures()
