#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from viewer.__data__ import ARE_YOU_SURE_YOU_WANTO_TO
from viewer.__data__ import BACK
from viewer.__data__ import IBM_POWERKVM
from viewer.__data__ import OK


#
# CONSTANTS
#


#
# CODE
#
class Confirmation:
    """
    Confirm operations which will be done on disk
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters. Valid keys:
                data dict installed model
                @IMPROVEMENT: entire model should not be provided to a
                    screen
        """

        self.__screen = screen

        self.__msg = TextboxReflowed(60, ARE_YOU_SURE_YOU_WANTO_TO.localize())

        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(), "ok"),
            (BACK.localize(), "back")])

        self.__grid = GridForm(self.__screen, IBM_POWERKVM.localize() % params["productVersion"], 1, 3)
        self.__grid.add(self.__msg, 0, 1)
        self.__grid.add(self.__buttonsBar, 0, 2)

    def run(self):
        """
        Draws the screen

        Returns:
            dict: screen output parameters. Valid keys:
                pressedButton str pressed button ID
        """

        result = self.__grid.run()
        self.__screen.popWindow()

        rc = self.__buttonsBar.buttonPressed(result)

        return {"pressedButton": rc}
