# -*- coding: utf-8 -*-

#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======



#
# IMPORTS
#
from snack import *

from viewer.__data__ import BACK
from viewer.__data__ import LICENSE_BUTTON_ACCEPT
from viewer.__data__ import LICENSE_BUTTON_DECLINE
from viewer.__data__ import OK
from viewer.__data__ import WELCOME_IBM_POWERKVM


#
# CONSTANTS
#
ACCEPT_LABEL = 'accept'
DECLINE_LABEL = 'decline'
OK_LABEL = 'ok'
BACK_LABEL = 'back'


#
# CODE
#
class LicenseMainWindow(object):
    """
    Implements the license main window
    """
    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance

            params (dict): screen input parameters. Valid keys:
                license str license content
                accept if license UI has accept/reject buttons
        """
        self.__screen = screen
        self.__license = params["license"]
        self.__accept = params["accept"]
        self.__msg  = Textbox(70, 8, "", scroll = 1, wrap = 1)
        self.__acceptButton = ButtonBar(self.__screen, [(LICENSE_BUTTON_ACCEPT.localize(), ACCEPT_LABEL)])
        self.__declineButton = ButtonBar(self.__screen, [(LICENSE_BUTTON_DECLINE.localize(), DECLINE_LABEL)])
        self.__defaultButton = ButtonBar(self.__screen, [(OK.localize(), OK_LABEL), (BACK.localize(), BACK_LABEL)])

        self.__grid = GridForm(self.__screen, WELCOME_IBM_POWERKVM.localize() % params["productVersion"], 1, 5)
        self.__grid.add(self.__msg, 0, 0)

    def run(self):
        """
        Displays the window to the user

        Returns:
            dict: screen output parameters. Valid keys:
                accepted bool if license was accepted by user
        """
        if self.__accept:
            self.__grid.add(self.__acceptButton, 0, 2)
            self.__grid.add(self.__declineButton, 0, 4)

        else:
            self.__grid.add(TextboxReflowed(70, '  '), 0, 1)
            self.__grid.add(self.__defaultButton, 0, 2)

        self.__msg.setText(self.__license)
        self.__screen.refresh()
        result = self.__grid.run()
        self.__screen.popWindow()

        if self.__accept and self.__acceptButton.buttonPressed(result) == ACCEPT_LABEL:
            return {"accepted": True}

        elif not self.__accept and self.__defaultButton.buttonPressed(result) == OK_LABEL:
            return {"accepted": True}

        return {"accepted": False}
