#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from viewer.__data__ import BACK
from viewer.__data__ import DOWN
from viewer.__data__ import EDIT
from viewer.__data__ import LISTNETIFACE_CONFIG_NET
from viewer.__data__ import LISTNETIFACE_SELECT_DEVICE
from viewer.__data__ import OK
from viewer.__data__ import UP

#
# CONSTANTS
#


#
# CODE
#
class ListNetworkifaces:
    """
    Represents the network interface list screen
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters
        """
        self.__screen = screen
        self.__nwInterfaces = params["nwInterfaces"]
        self.__activeNwInterfaces = params["activeNwInterfaces"]
        self.__msg = TextboxReflowed(40, LISTNETIFACE_SELECT_DEVICE.localize())
        self.__list = Listbox(5, scroll=1, returnExit=1)
        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(), "ok"), (EDIT.localize(), "edit"),
            (BACK.localize(), "back")])

    def __show(self):
        """
        Shows screen once
        """
        self.__grid = GridForm(self.__screen, LISTNETIFACE_CONFIG_NET.localize(), 1, 3)
        self.__grid.add(self.__msg, 0, 0)
        self.__grid.add(self.__list, 0, 1)
        self.__grid.add(self.__buttonsBar, 0, 2)


    def run(self):
        """
        Draws the screen

        Returns:
            dict: screen output parameters. Valid keys:
                pressedButton str pressed button ID
                selectedNwInterfaceName str selected network interface
                    name
                selectedNwInterfaceMacAddress str selected network
                    interface MAC address
        """
        sortedDevices = sorted(self.__nwInterfaces)
        for dev in sortedDevices:
            bridge = "br%s" % dev
            if dev in self.__activeNwInterfaces:
                active = UP.localize()
            elif bridge in self.__activeNwInterfaces:
                active = UP.localize() + ' - %s' % bridge
            else:
                active = DOWN.localize()
            display = "%s [ %s ] (%s)" % (dev, self.__nwInterfaces.get(dev), active)
            self.__list.append(display, dev)

        self.__show()
        result = self.__grid.run()
        self.__screen.popWindow()

        rc = self.__buttonsBar.buttonPressed(result)
        return {"pressedButton": rc,
                "selectedNwInterfaceName": self.__list.current(),
                "selectedNwInterfaceMacAddress": self.__nwInterfaces.get(self.__list.current())}
