#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from viewer.__data__ import BACK
from viewer.__data__ import HELP_LINE
from viewer.__data__ import OK
from viewer.__data__ import SELECT_ONE_OF_THE_OPTIONS_BELOW
from viewer.__data__ import WELCOME_IBM_POWERKVM

#
# CONSTANTS
#


#
# CODE
#
class Menu:
    """
    Welcome page for the installer application
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters
        """
        self.__screen = screen

        self.__msg = TextboxReflowed(40,
                SELECT_ONE_OF_THE_OPTIONS_BELOW.localize())
        self.__list = Listbox(5, returnExit=0)

        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(), "ok"),
            (BACK.localize(), "back")])

        self.__grid = GridForm(self.__screen, WELCOME_IBM_POWERKVM.localize() % params["productVersion"], 1, 3)
        self.__grid.add(self.__msg, 0, 0)
        self.__grid.add(self.__list, 0, 1, (0,1,0,0))
        self.__grid.add(self.__buttonsBar, 0, 2, (0,1,0,0))


        self.__screen.pushHelpLine(HELP_LINE.localize())

        self.__setMenuOptions(params["options"])

    def run(self):
        """
        Draws the screen

        Returns:
            dict: screen output parameters. Valid keys:
                pressedButton str pressed button ID
                installationType str installation type
        """
        # run the list and show the window
        result = self.__grid.run()
        self.__screen.popWindow()

        rc = self.__buttonsBar.buttonPressed(result)

        # return the content to the controller
        return {"pressedButton": rc,
                "installationType": self.__list.current()}

    def __setMenuOptions(self, options):
        """
        Configures which options will be displayed on KoP menu install.

        Args:
             options ([(str, ?)]): list with tuples ('text', optionKey)
        """
        # invalid given parameter: abort
        if not isinstance(options, list):
            return

        # add options to screen list
        for opt in options:
            self.__list.append(opt[0], opt[1])
